@@ -1,7 +1,7 @@
 #ifndef FIO_IOLOG_H
 #define FIO_IOLOG_H
 
-#include "ieee754.h"
+#include "lib/ieee754.h"
 
 /*
  * Use for maintaining statistics
